@@ -15,7 +15,13 @@ __all__ = [
     "METHOD_ALL",
 ]
 
+from .httpserver import METHOD_ALL
+from .httpserver import URI_DEFAULT
+from .httpserver import Error
+from .httpserver import HeaderValueMatcher
 from .httpserver import HTTPServer
-from .httpserver import HTTPServerError, Error, NoHandlerError
-from .httpserver import WaitingSettings, HeaderValueMatcher, RequestHandler
-from .httpserver import URIPattern, URI_DEFAULT, METHOD_ALL
+from .httpserver import HTTPServerError
+from .httpserver import NoHandlerError
+from .httpserver import RequestHandler
+from .httpserver import URIPattern
+from .httpserver import WaitingSettings
